@@ -1,7 +1,7 @@
 package Galileo;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = 0.004;
+our $VERSION = 0.005;
 $VERSION = eval $VERSION;
 
 use File::Basename 'dirname';
@@ -22,11 +22,13 @@ has db => sub {
   return $schema;
 };
 
+has config_file => 'galileo.conf';
+
 sub startup {
   my $app = shift;
 
   $app->plugin( Config => { 
-    file => 'galileo.conf',
+    file => $app->config_file,
     default => {
       db_schema  => 'Galileo::DB::Schema',
       db_connect => [
@@ -168,11 +170,51 @@ Galileo - A simple modern CMS built on Mojolicious
 
 =head1 DESCRIPTION
 
-L<Galileo> is a Perl CMS with some modern features. Run C<galileo setup> to setup a database. Afterward the database is ready, you can run C<galileo daemon> or use L<morbo> or L<hypnotoad> to start the server.
+L<Galileo> is a Perl CMS with some modern features. It uses client-side markdown rendering and websockets for saving page data without reloading. L<Galileo> relies on many other great open-source projects, see more in the L</"TECHNOLOGIES USED"> section.
 
 This release is very young, don't expect anything not to break, for now. Bug reports very welcome.
 
-=head1 SEE ALSO
+=head1 INSTALLATION
+
+L<Galileo> uses well-tested and widely-used CPAN modules, so installation should be as simple as
+
+    $ cpanm Galileo
+
+when using L<App::cpanminus>. Of course you can use your favorite CPAN client or install manually by cloning the L</"SOURCE REPOSITORY">.
+
+=head1 SETUP
+
+L<Galileo> installs a helper script C<galileo>. It inherits from the L<mojo> command, but it provides extra functions specifically for use with Galileo.
+
+=head2 config
+
+ $ galileo config [options]
+
+This command writes a configuration file in your current working directory. It uses the preset defaults for all values, except that it prompts for a secret. This can be any string, however stronger is better. You do not need to memorize it or remember it. This secret protects the cookies employed by Galileo from being tampered with on the client side.
+
+L<Galileo> does not need to be configured, however it is recommended to do so to set your application's secret. 
+
+The C<--force> option may be passed to overwrite any configuration file in the current working directory. The default is to die if such a configuration file is found.
+
+=head2 setup
+
+ $ galileo setup
+
+Run C<galileo setup> to setup a database. This step is required. It will use the default DBI settings (SQLite) or whatever is setup in the configuration file generated by the C<config> command.
+
+=head1 RUNNING THE APPLICATION
+
+ $ galileo daemon
+
+After the database is has been setup, you can run C<galileo daemon> to start the server. 
+
+You may also use L<morbo> (Mojolicious' development server) or L<hypnotoad> (Mojolicious' production server). You may even use any other server that Mojolicious supports, however for full functionality it must support websockets. When doing so you will need to know the full path to the C<galileo> application. A useful recipe might be
+
+ $ hypnotoad `which galileo`
+
+or replace C<hypnotoad> with your server of choice.
+
+=head1 TECHNOLOGIES USED
 
 =over
 
@@ -202,6 +244,16 @@ L<HumaneJS|http://wavded.github.com/humane-js/> - A simple, modern, browser noti
 
 =back
 
+=head1 SEE ALSO
+
+=over
+
+=item *
+
+L<Contenticious> - File-based Markdown website application
+
+=back
+
 =head1 SOURCE REPOSITORY
 
 L<http://github.com/jberger/Galileo>
